# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 Allen Lowe <lallenlowe@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE


import os
from ConfigParser import SafeConfigParser, NoSectionError, NoOptionError
from xdg.BaseDirectory import xdg_config_home

class DexterConfig(SafeConfigParser):
    
    DEFAULTS = [{
                "name":"general",
                "keys":{
                        "hpane_width":175,
                        },
                }]
    
    CONFIGDIR = os.path.join(xdg_config_home, "dexter")
    CONFIGFILE = os.path.join(CONFIGDIR, "dexter.conf")
    
    def __init__(self):
        SafeConfigParser.__init__(self)
        if not os.path.isdir(self.CONFIGDIR):
            os.makedirs(self.CONFIGDIR)
        if not os.path.isfile(self.CONFIGFILE):
            self.create_default()
            self.write()
        self.read(self.CONFIGFILE)
    
    def create_default(self):
        # For every section
        for section in self.DEFAULTS:
            # Add the section
            self.add_section(section["name"])
            # And add every key in it, with its default value
            for key in section["keys"]:
                value = section["keys"][key]
                self.set(section["name"], key, value)

    def find_default(self, section, key):
        for d_section in self.DEFAULTS:
            if d_section["name"] == section:
                for d_key in d_section["keys"]:
                    if d_key == key:
                        return d_section["keys"][key]
        
    def get(self, section, key):
        try:
            return SafeConfigParser.get(self, section, key)
        except NoSectionError:
            default = self.find_default(section, key)
            self.set(section, key, default)
            self.write()
            return default
        except NoOptionError:
            default = self.find_default(section, key)
            self.set(section, key, default)
            self.write()
            return default
    
    def set(self, section, option, value):
        # If the section referred to doesn't exist (rare case),
        # then create it
        if not self.has_section(section):
            self.add_section(section)
        SafeConfigParser.set(self, section, option, str(value))
        self.write()
        
    def write(self):
        file_ = open(self.CONFIGFILE, "w")
        SafeConfigParser.write(self, file_)
        file_.close()
    
