# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2010 Allen Lowe <lallenlowe@gmail.com>
# This program is free software: you can redistribute it and/or modify it 
# under the terms of the GNU General Public License version 3, as published 
# by the Free Software Foundation.
# 
# This program is distributed in the hope that it will be useful, but 
# WITHOUT ANY WARRANTY; without even the implied warranties of 
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR 
# PURPOSE.  See the GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License along 
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

"""
    This module provides custom widgets that are used and re-used by Dexter.
"""

import gtk
import glib
import pango
import os
import sys
import warnings

from dexter.helpers import get_builder
import dexter.backend.utilities as utilities

import gettext
from gettext import gettext as _
gettext.textdomain('dexter')


class RemoveButton(gtk.Button):
    """a gtk.Button for removing parent data field hboxes"""
    __gtype_name__ = 'DataButton'

    def __init__(self, group=[]):
        gtk.Button.__init__(self)
        self.image_rm = gtk.Image()
        self.image_rm.set_from_stock("gtk-remove", gtk.ICON_SIZE_BUTTON)
        self.set_image(self.image_rm)
        self.set_relief(gtk.RELIEF_NONE)
        self.connect("clicked", self.button_clicked, group)

    def button_clicked(self, widget, group):
        group.remove(self.get_parent())
        self.get_parent().destroy()


class AddressRemoveButton(RemoveButton):
    """fix RemoveButton to work with AddressVBox"""
    __gtype_name__ = 'AddressRemoveButton'

    def button_clicked(self, widget, group):
        group.remove(self.get_parent().get_parent())
        self.get_parent().get_parent().destroy()


class URLDataButton(gtk.Button):  # not being used for now, because buttons use too much vertical space
    """a gtk.Button for emails etc. in the contact viewer"""
    __gtype_name__ = 'URLDataButton'

    def __init__(self, text, url):
        gtk.Button.__init__(self)
        self.set_alignment(0.0, 0.5)
#        self.set_size_request(-1, 20)
        self.set_sensitive(True)
        self.set_relief(gtk.RELIEF_NONE)
        self.set_label(text+"\n"+text)
        self.url = url
        self.connect('clicked', self.open_url)
        
    def open_url(self, widget):
        try:
            glib.spawn_async(["/usr/bin/xdg-open", self.url])
        except:
            gtk.show_uri(None, self.url, gtk.gdk.CURRENT_TIME)
